class oci::swiftcommon(
){

  package { 'swift-drive-audit':
    ensure => present,
  }

  swift_drive_audit_config {
    'drive-audit/log_file_pattern': value => '/var/log/kern-legacy.*[!.][!g][!z]';
  }

  file { '/etc/rsyslog.d/10-kern-legacy.conf':
    ensure => present,
    source => 'puppet:///modules/oci/rsyslog/10-kern-legacy.conf',
    path => '/etc/rsyslog.d/10-kern-legacy.conf',
    group => 'root',
    owner => 'root',
    mode => '0644',
    require => [Package['rsyslog']],
    notify  => Service['rsyslog'],
  }

  logrotate::rule { 'kern-legacy':
    path           => '/var/log/kern-legacy.log',
    rotate         => '4',
    rotate_every   => 'week',
    missingok      => true,
    ifempty        => false,
    compress       => true,
    delaycompress  => true,
    postrotate     => '/usr/lib/rsyslog/rsyslog-rotate',
  }

  file { '/etc/rsyslog.d/swift.conf':
    ensure => absent,
  }

  file { '/etc/rsyslog.d/20-swift.conf':
    ensure  => present,
    source  => "puppet:///modules/oci/rsyslog/20-swift.conf",
    require => [Package['rsyslog'], File['/var/log/swift']],
    notify  => Service['rsyslog'],
  }

  # setgid so created files inherit the group
  file { '/var/log/swift':
    ensure => directory,
    mode   => '2750',
    owner  => 'swift',
    group  => 'adm',
  }
}
